@@ -18,7 +18,10 @@ def load_json(file_path):
         return json.load(f)
 
 
-def save_json(data, filename, save_pretty=False, sort_keys=False):
+def save_json(data, filename,
+              save_pretty=True,
+              sort_keys=True,
+              ensure_ascii=True):
     """Save json function.
 
     Parameters
@@ -31,7 +34,10 @@ def save_json(data, filename, save_pretty=False, sort_keys=False):
     filename = str(filename)
     with open(filename, "w") as f:
         if save_pretty:
-            f.write(json.dumps(data, indent=4, sort_keys=sort_keys))
+            f.write(json.dumps(data, indent=4,
+                               ensure_ascii=ensure_ascii,
+                               sort_keys=sort_keys,
+                               separators=(',', ': ')))
         else:
             json.dump(data, f)
         f.write('\n')
